summaryrefslogtreecommitdiff
path: root/examples/cmd_as_argument.py
diff options
context:
space:
mode:
Diffstat (limited to 'examples/cmd_as_argument.py')
-rwxr-xr-xexamples/cmd_as_argument.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/examples/cmd_as_argument.py b/examples/cmd_as_argument.py
index 33ad699b..39332203 100755
--- a/examples/cmd_as_argument.py
+++ b/examples/cmd_as_argument.py
@@ -30,8 +30,8 @@ class CmdLineApp(cmd2.Cmd):
def __init__(self):
shortcuts = dict(cmd2.DEFAULT_SHORTCUTS)
shortcuts.update({'&': 'speak'})
- # Set use_ipython to True to enable the "ipy" command which embeds and interactive IPython shell
- super().__init__(allow_cli_args=False, use_ipython=True, multiline_commands=['orate'], shortcuts=shortcuts)
+ # Set include_ipy to True to enable the "ipy" command which runs an interactive IPython shell
+ super().__init__(allow_cli_args=False, include_ipy=True, multiline_commands=['orate'], shortcuts=shortcuts)
self.self_in_py = True
self.maxrepeats = 3